@@ -44,8 +44,9 @@ $tabs['medband'] = translate('MediumBW');
 $tabs['lowband'] = translate('LowBW');
 $tabs['users'] = translate('Users');
 $tabs['control'] = translate('Control');
+$tabs['privacy'] = translate('Privacy');
 
-if ( isset($_REQUEST['tab']) )
+if (isset($_REQUEST['tab']))
   $tab = validHtmlStr($_REQUEST['tab']);
 else
   $tab = 'system';
@@ -53,16 +54,15 @@ else
 $focusWindow = true;
 
 xhtmlHeaders(__FILE__, translate('Options'));
-
+getBodyTopHTML();
+echo getNavBarHTML();
 ?>
-<body>
-  <?php echo getNavBarHTML(); ?>
   <div class="container-fluid">
     <div class="row flex-nowrap">
       <nav id="sidebar">
         <ul class="nav nav-pills flex-column h-100">
 <?php
-foreach ( $tabs as $name=>$value ) {
+foreach ($tabs as $name=>$value) {
 ?>
           <li class="nav-item form-control-sm my-1"><a class="nav-link<?php echo $tab == $name ? ' active' : '' ?>" href="?view=<?php echo $view ?>&amp;tab=<?php echo $name ?>"><?php echo $value ?></a></li>
 <?php
@@ -181,7 +181,7 @@ foreach ( array_map('basename', glob('skins/'.$skin.'/css/*', GLOB_ONLYDIR)) as
           </tbody>
         </table>
         <div id="contentButtons">
-          <?php echo makeButton('?view=user&uid=0', 'AddNewUser', canEdit('System')); ?>
+          <?php echo makeButton('?view=user&uid=0', 'AddNewUser', $canEdit); ?>
           <button type="submit" class="btn-danger" name="deleteBtn" value="Delete" disabled="disabled"><?php echo translate('Delete') ?></button>
         </div>
       </form>
@@ -194,6 +194,14 @@ foreach ( array_map('basename', glob('skins/'.$skin.'/css/*', GLOB_ONLYDIR)) as
       }
       // Have to do this 
       header('Location: '.$redirect);
+} else if ($tab == 'privacy') {
+      if (canView('System')) {
+        $redirect = '?view=privacy';
+      } else {
+        $redirect = '?view=error';
+      }
+      // Have to do this 
+      header('Location: '.$redirect);
 } else if ( $tab == 'servers' ) {
       ?>
       <form name="serversForm" method="post" action="?">
@@ -394,15 +402,17 @@ foreach ( array_map('basename', glob('skins/'.$skin.'/css/*', GLOB_ONLYDIR)) as
     $configCats = array();
 
     $result = $dbConn->query('SELECT * FROM `Config` ORDER BY `Id` ASC');
-    if ( !$result )
+    if ( !$result ) {
       echo mysql_error();
-    while ( $row = dbFetchNext($result) ) {
-      $config[$row['Name']] = $row;
-      if ( !($configCat = &$configCats[$row['Category']]) ) {
-        $configCats[$row['Category']] = array();
-        $configCat = &$configCats[$row['Category']];
+    } else {
+      while ( $row = dbFetchNext($result) ) {
+        $config[$row['Name']] = $row;
+        if ( !($configCat = &$configCats[$row['Category']]) ) {
+          $configCats[$row['Category']] = array();
+          $configCat = &$configCats[$row['Category']];
+        }
+        $configCat[$row['Name']] = $row;
       }
-      $configCat[$row['Name']] = $row;
     }
 
     if ( $tab == 'system' ) {
@@ -444,6 +454,13 @@ foreach ( array_map('basename', glob('skins/'.$skin.'/css/*', GLOB_ONLYDIR)) as
           return $name;
         }
         $configCats[$tab]['ZM_TIMEZONE']['Hint'] = array(''=> translate('TZUnset')) + timezone_list();
+        $configCats[$tab]['ZM_LOCALE_DEFAULT']['Hint'] = array(''=> translate('System Default'));
+        $locales = ResourceBundle::getLocales('');
+        if ($locales) {
+          foreach ( $locales as $locale) {
+            $configCats[$tab]['ZM_LOCALE_DEFAULT']['Hint'][$locale] = $locale;
+          }
+        }
     } # end if tab == system
 ?>
       <form name="optionsForm" class="" method="post" action="?">
@@ -455,87 +472,87 @@ foreach ( array_map('basename', glob('skins/'.$skin.'/css/*', GLOB_ONLYDIR)) as
         foreach ( $configCat as $name=>$value ) {
           $shortName = preg_replace( '/^ZM_/', '', $name );
           $optionPromptText = !empty($OLANG[$shortName])?$OLANG[$shortName]['Prompt']:$value['Prompt'];
+          $optionCanEdit = $canEdit && !$value['System'];
 ?>
-            <div class="form-group form-row">
-              <label for="<?php echo $name ?>" class="col-md-4 control-label text-md-right"><?php echo $shortName ?></label>
-              <div class="col-md">
+        <div class="form-group form-row">
+          <label for="<?php echo $name ?>" class="col-md-4 control-label text-md-right"><?php echo $shortName ?></label>
+          <div class="col-md">
 <?php   
-        if ( $value['Type'] == 'boolean' ) {
-?>
-              <input type="checkbox" id="<?php echo $name ?>" name="newConfig[<?php echo $name ?>]" value="1"<?php if ( $value['Value'] ) { ?> checked="checked"<?php } ?><?php echo $canEdit?'':' disabled="disabled"' ?>/>
-<?php
-        } elseif ( is_array($value['Hint']) ) {
-          echo htmlSelect("newConfig[$name]", $value['Hint'], $value['Value']);
-        } elseif ( preg_match('/\|/', $value['Hint']) ) {
-?>
-
-<?php
+          if ($value['Type'] == 'boolean') {
+            echo '<input type="checkbox" id="'.$name.'" name="newConfig['.$name.']" value="1"'.
+              ( $value['Value'] ? ' checked="checked"' : '').
+              ( $optionCanEdit ? '' : ' disabled="disabled"').' />'.PHP_EOL;
+          } else if ( is_array($value['Hint']) ) {
+            echo htmlSelect("newConfig[$name]", $value['Hint'], $value['Value']);
+          } else if ( preg_match('/\|/', $value['Hint']) ) {
             $options = explode('|', $value['Hint']);
-            if ( count($options) > 3 ) {
+            if (count($options) > 3) {
 ?>
-                <select class="form-control-sm" name="newConfig[<?php echo $name ?>]"<?php echo $canEdit?'':' disabled="disabled"' ?>>
-<?php
-                foreach ( $options as $option ) {
-                  if ( preg_match('/^([^=]+)=(.+)$/', $option, $matches) ) {
-                    $optionLabel = $matches[1];
-                    $optionValue = $matches[2];
-                  } else {
-                    $optionLabel = $optionValue = $option;
-                  }
-?>
-                  <option value="<?php echo $optionValue ?>"<?php if ( $value['Value'] == $optionValue ) { echo ' selected="selected"'; } ?>><?php echo htmlspecialchars($optionLabel) ?></option>
+              <select class="form-control-sm" name="newConfig[<?php echo $name ?>]"<?php echo $optionCanEdit?'':' disabled="disabled"' ?>>
 <?php
+              foreach ( $options as $option ) {
+                if ( preg_match('/^([^=]+)=(.+)$/', $option, $matches) ) {
+                  $optionLabel = $matches[1];
+                  $optionValue = $matches[2];
+                } else {
+                  $optionLabel = $optionValue = $option;
                 }
 ?>
-                </select>
+                <option value="<?php echo $optionValue ?>"<?php if ( $value['Value'] == $optionValue ) { echo ' selected="selected"'; } ?>><?php echo htmlspecialchars($optionLabel) ?></option>
+<?php
+              } # end foreach option
+?>
+              </select>
 <?php
             } else {
-                foreach ( $options as $option ) {
-                  if ( preg_match('/^([^=]+)=(.+)$/', $option) ) {
-                    $optionLabel = $matches[1];
-                    $optionValue = $matches[2];
-                  } else {
-                    $optionLabel = $optionValue = $option;
-                  }
+              foreach ( $options as $option ) {
+                if ( preg_match('/^([^=]+)=(.+)$/', $option) ) {
+                  $optionLabel = $matches[1];
+                  $optionValue = $matches[2];
+                } else {
+                  $optionLabel = $optionValue = $option;
+                }
 ?>
                 <label class="font-weight-bold  form-control-sm">
-                  <input type="radio" id="<?php echo $name.'_'.preg_replace('/[^a-zA-Z0-9]/', '', $optionValue) ?>" name="newConfig[<?php echo $name ?>]" value="<?php echo $optionValue ?>"<?php if ( $value['Value'] == $optionValue ) { ?> checked="checked"<?php } ?><?php echo $canEdit?'':' disabled="disabled"' ?>/>
+                  <input type="radio" id="<?php echo $name.'_'.preg_replace('/[^a-zA-Z0-9]/', '', $optionValue) ?>" name="newConfig[<?php echo $name ?>]" value="<?php echo $optionValue ?>"<?php if ( $value['Value'] == $optionValue ) { ?> checked="checked"<?php } ?><?php echo $optionCanEdit?'':' disabled="disabled"' ?>/>
                   <?php echo htmlspecialchars($optionLabel) ?>
                 </label>
 <?php
-                }
-            }
+              } # end forach option
+            } # end if how many options, which input type display
 ?>
 <?php
-        } else if ( $value['Type'] == 'text' ) {
+          } else if ($value['Type'] == 'text') {
 ?>
-              <textarea class="form-control-sm" id="<?php echo $name ?>" name="newConfig[<?php echo $name ?>]" rows="5" cols="40"<?php echo $canEdit?'':' disabled="disabled"' ?>><?php echo validHtmlStr($value['Value']) ?></textarea>
+            <textarea class="form-control-sm" id="<?php echo $name ?>" name="newConfig[<?php echo $name ?>]" rows="5" cols="40"<?php echo $optionCanEdit?'':' disabled="disabled"' ?>><?php echo validHtmlStr($value['Value']) ?></textarea>
 <?php
-        } else if ( $value['Type'] == 'integer' ) {
+          } else if ( $value['Type'] == 'integer' ) {
 ?>
-              <input type="number" class="form-control-sm" id="<?php echo $name ?>" name="newConfig[<?php echo $name ?>]" value="<?php echo validHtmlStr($value['Value']) ?>" <?php echo $canEdit?'':' disabled="disabled"' ?>/>
+            <input type="number" class="form-control-sm" id="<?php echo $name ?>" name="newConfig[<?php echo $name ?>]" value="<?php echo validHtmlStr($value['Value']) ?>" <?php echo $optionCanEdit?'':' disabled="disabled"' ?>/>
 <?php
-        } else if ( $value['Type'] == 'hexadecimal' ) {
+          } else if ( $value['Type'] == 'hexadecimal' ) {
 ?>
-              <input type="text" class="form-control-sm" id="<?php echo $name ?>" name="newConfig[<?php echo $name ?>]" value="<?php echo validHtmlStr($value['Value']) ?>" <?php echo $canEdit?'':' disabled="disabled"' ?>/>
+            <input type="text" class="form-control-sm" id="<?php echo $name ?>" name="newConfig[<?php echo $name ?>]" value="<?php echo validHtmlStr($value['Value']) ?>" <?php echo $optionCanEdit?'':' disabled="disabled"' ?>/>
 <?php
-        } else if ( $value['Type'] == 'decimal' ) {
+          } else if ( $value['Type'] == 'decimal' ) {
 ?>
-              <input type="text" class="form-control-sm" id="<?php echo $name ?>" name="newConfig[<?php echo $name ?>]" value="<?php echo validHtmlStr($value['Value']) ?>" <?php echo $canEdit?'':' disabled="disabled"' ?>/>
+            <input type="text" class="form-control-sm" id="<?php echo $name ?>" name="newConfig[<?php echo $name ?>]" value="<?php echo validHtmlStr($value['Value']) ?>" <?php echo $optionCanEdit?'':' disabled="disabled"' ?>/>
 <?php
-        } else {
+          } else {
 ?>
-              <input type="text" class="form-control-sm" id="<?php echo $name ?>" name="newConfig[<?php echo $name ?>]" value="<?php echo validHtmlStr($value['Value']) ?>" <?php echo $canEdit?'':' disabled="disabled"' ?>/>
+            <input type="text" class="form-control-sm" id="<?php echo $name ?>" name="newConfig[<?php echo $name ?>]" value="<?php echo validHtmlStr($value['Value']) ?>" <?php echo $optionCanEdit?'':' disabled="disabled"' ?>/>
 <?php
-        }
+          }
+          if ($value['Value'] != constant($name)) {
+            echo '<p class="warning">Note: This value has been overriden via configuration files in '.ZM_CONFIG. ' or ' . ZM_CONFIG_SUBDIR.'.<br/>The overriden value is: '.constant($name).'</p>'.PHP_EOL;
+          }
 ?>
-              <span class="form-text form-control-sm"><?php echo validHtmlStr($optionPromptText); echo makeHelpLink($name) ?></span>
-	    </div><!-- End .col-sm-9 -->
-            </div><!-- End .form-group -->
+            <span class="form-text form-control-sm"><?php echo validHtmlStr($optionPromptText); echo makeHelpLink($name) ?></span>
+	        </div><!-- End .col-sm-9 -->
+        </div><!-- End .form-group -->
 <?php
     }
 ?>
-
         <div id="contentButtons">
           <button type="submit" <?php echo $canEdit?'':' disabled="disabled"' ?>><?php echo translate('Save') ?></button>
         </div>
@@ -543,9 +560,6 @@ foreach ( array_map('basename', glob('skins/'.$skin.'/css/*', GLOB_ONLYDIR)) as
 <?php
 }
 ?>
-
-
-
     </div><!-- end #options -->
 	</div>
 </div> <!-- end row -->
